@@ -9,7 +9,7 @@ Command = collections.namedtuple('Command', 'regex category usage function')
 # input types
 WORD = r'[^\W\d][-\w\s]{,100}'
 RS = r'(?:(?:repeat|shuffle|-[avfw])\s*)'
-PL = r'\S*?((?:RD|PL)[-_0-9a-zA-Z]+)\s*'
+PL = r'\S*?((?:RD|PL|LL)[-_0-9a-zA-Z]+)\s*'
 
 
 def command(regex):
@@ -23,5 +23,5 @@ def command(regex):
 
 
 # Placed at bottom to deal with cyclic imports
-from . import download, search, album_search, misc, config, local_playlist
-from . import play, songlist
+from . import download, search, album_search, spotify_playlist, misc, config, local_playlist
+from . import play, songlist, generate_playlist, lastfm
